@@ -20,7 +20,7 @@
 #include "orafce.h"
 #include "builtins.h"
 
-bool orafce_emit_error_on_date_bug = true;
+bool		orafce_emit_error_on_date_bug = true;
 
 #define ENABLE_INTERNATIONALIZED_WEEKDAY
 
@@ -38,11 +38,11 @@ typedef struct WeekDays
 static const WeekDays WEEKDAYS[] =
 {
 	/* Japanese, UTF8 */
-	{ PG_UTF8, { "\346\227\245", "\346\234\210", "\347\201\253", "\346\260\264", "\346\234\250", "\351\207\221", "\345\234\237" } },
+	{PG_UTF8, {"\346\227\245", "\346\234\210", "\347\201\253", "\346\260\264", "\346\234\250", "\351\207\221", "\345\234\237"}},
 	/* Japanese, EUC_JP */
-	{ PG_EUC_JP, { "\306\374", "\267\356", "\262\320", "\277\345", "\314\332", "\266\342", "\305\332" } },
+	{PG_EUC_JP, {"\306\374", "\267\356", "\262\320", "\277\345", "\314\332", "\266\342", "\305\332"}},
 	/* Japanese, EUC_JIS_2004 (same as EUC_JP) */
-	{ PG_EUC_JIS_2004, { "\306\374", "\267\356", "\262\320", "\277\345", "\314\332", "\266\342", "\305\332" } },
+	{PG_EUC_JIS_2004, {"\306\374", "\267\356", "\262\320", "\277\345", "\314\332", "\266\342", "\305\332"}},
 };
 
 static const WeekDays *mru_weekdays = NULL;
@@ -50,20 +50,21 @@ static const WeekDays *mru_weekdays = NULL;
 static int
 weekday_search(const WeekDays *weekdays, const char *str, size_t len)
 {
-	int		i;
+	int			i;
 
 	for (i = 0; i < 7; i++)
 	{
-		size_t	n = strlen(weekdays->names[i]);
+		size_t		n = strlen(weekdays->names[i]);
+
 		if (n > len)
-			continue;	/* too short */
+			continue;			/* too short */
 		if (pg_strncasecmp(weekdays->names[i], str, n) == 0)
 			return i;
 	}
-	return -1;	/* not found */
+	return -1;					/* not found */
 }
 
-#endif	/* ENABLE_INTERNATIONALIZED_WEEKDAY */
+#endif							/* ENABLE_INTERNATIONALIZED_WEEKDAY */
 
 #define CASE_fmt_YYYY	case 0: case 1: case 2: case 3: case 4: case 5: case 6:
 #define CASE_fmt_IYYY	case 7: case 8: case 9: case 10:
@@ -81,15 +82,15 @@ weekday_search(const WeekDays *weekdays, const char *str, size_t len)
 static STRING_PTR_FIELD_TYPE date_fmt[] =
 {
 	"Y", "Yy", "Yyy", "Yyyy", "Year", "Syyyy", "syear",
-	"I", "Iy", "Iyy", "Iyyy",
-	"Q", "Ww", "Iw", "W",
-	"Day", "Dy", "D",
-	"Month", "Mon", "Mm", "Rm",
-	"Cc", "Scc",
-	"Ddd", "Dd", "J",
-	"Hh", "Hh12", "Hh24",
-	"Mi",
-	NULL
+		"I", "Iy", "Iyy", "Iyyy",
+		"Q", "Ww", "Iw", "W",
+		"Day", "Dy", "D",
+		"Month", "Mon", "Mm", "Rm",
+		"Cc", "Scc",
+		"Ddd", "Dd", "J",
+		"Hh", "Hh12", "Hh24",
+		"Mi",
+		NULL
 };
 
 STRING_PTR_FIELD_TYPE ora_days[] = {"Sunday", "Monday", "Tuesday", "Wednesday",
@@ -130,7 +131,7 @@ PG_FUNCTION_INFO_V1(orafce_sys_extract_utc_oracle_date);
 int
 ora_seq_search(const char *name, STRING_PTR_FIELD_TYPE array[], size_t max)
 {
-	int		i;
+	int			i;
 
 	if (!*name)
 		return -1;
@@ -141,13 +142,13 @@ ora_seq_search(const char *name, STRING_PTR_FIELD_TYPE array[], size_t max)
 			pg_strncasecmp(name, array[i], max) == 0)
 			return i;
 	}
-	return -1;	/* not found */
+	return -1;					/* not found */
 }
 
 static int
 ora_seq_prefix_search(const char *name, STRING_PTR_FIELD_TYPE array[], int max)
 {
-	int		i;
+	int			i;
 
 	if (!*name)
 		return -1;
@@ -157,7 +158,7 @@ ora_seq_prefix_search(const char *name, STRING_PTR_FIELD_TYPE array[], int max)
 		if (pg_strncasecmp(name, array[i], max) == 0)
 			return i;
 	}
-	return -1;	/* not found */
+	return -1;					/* not found */
 }
 
 /********************************************************************
@@ -178,12 +179,12 @@ ora_seq_prefix_search(const char *name, STRING_PTR_FIELD_TYPE array[], int max)
 Datum
 next_day(PG_FUNCTION_ARGS)
 {
-	DateADT day = PG_GETARG_DATEADT(0);
-	text *day_txt = PG_GETARG_TEXT_PP(1);
+	DateADT		day = PG_GETARG_DATEADT(0);
+	text	   *day_txt = PG_GETARG_TEXT_PP(1);
 	const char *str = VARDATA_ANY(day_txt);
-	int	len = VARSIZE_ANY_EXHDR(day_txt);
-	int off;
-	int d = -1;
+	int			len = VARSIZE_ANY_EXHDR(day_txt);
+	int			off;
+	int			d = -1;
 
 #ifdef ENABLE_INTERNATIONALIZED_WEEKDAY
 	/* Check mru_weekdays first for performance. */
@@ -197,8 +198,8 @@ next_day(PG_FUNCTION_ARGS)
 #endif
 
 	/*
-	 * Oracle uses only 3 heading characters of the input.
-	 * Ignore all trailing characters.
+	 * Oracle uses only 3 heading characters of the input. Ignore all trailing
+	 * characters.
 	 */
 	if (len >= 3 && (d = ora_seq_prefix_search(str, ora_days, 3)) >= 0)
 		goto found;
@@ -206,8 +207,8 @@ next_day(PG_FUNCTION_ARGS)
 #ifdef ENABLE_INTERNATIONALIZED_WEEKDAY
 	do
 	{
-		int		i;
-		int		encoding = GetDatabaseEncoding();
+		int			i;
+		int			encoding = GetDatabaseEncoding();
 
 		for (i = 0; i < (int) lengthof(WEEKDAYS); i++)
 		{
@@ -220,37 +221,37 @@ next_day(PG_FUNCTION_ARGS)
 				}
 			}
 		}
-	} while(0);
+	} while (0);
 #endif
 
 	CHECK_SEQ_SEARCH(-1, "DAY/Day/day");
 
 found:
-	off = d - j2day(day+POSTGRES_EPOCH_JDATE);
+	off = d - j2day(day + POSTGRES_EPOCH_JDATE);
 
-	PG_RETURN_DATEADT((off <= 0) ? day+off+7 : day + off);
+	PG_RETURN_DATEADT((off <= 0) ? day + off + 7 : day + off);
 }
 
 /* next_day(date, integer) is not documented in Oracle manual, but ... */
 Datum
 next_day_by_index(PG_FUNCTION_ARGS)
 {
-	DateADT day = PG_GETARG_DATEADT(0);
-	int		idx = PG_GETARG_INT32(1);
-	int		off;
+	DateADT		day = PG_GETARG_DATEADT(0);
+	int			idx = PG_GETARG_INT32(1);
+	int			off;
 
 	/*
 	 * off is 1..7 (Sun..Sat).
 	 *
-	 * TODO: It should be affected by NLS_TERRITORY. For example,
-	 * 1..7 should be interpreted as Mon..Sun in GERMAN.
+	 * TODO: It should be affected by NLS_TERRITORY. For example, 1..7 should
+	 * be interpreted as Mon..Sun in GERMAN.
 	 */
 	CHECK_SEQ_SEARCH((idx < 1 || 7 < idx) ? -1 : 0, "DAY/Day/day");
 
 	/* j2day returns 0..6 as Sun..Sat */
-	off = (idx - 1) - j2day(day+POSTGRES_EPOCH_JDATE);
+	off = (idx - 1) - j2day(day + POSTGRES_EPOCH_JDATE);
 
-	PG_RETURN_DATEADT((off <= 0) ? day+off+7 : day + off);
+	PG_RETURN_DATEADT((off <= 0) ? day + off + 7 : day + off);
 }
 
 /********************************************************************
@@ -271,11 +272,14 @@ next_day_by_index(PG_FUNCTION_ARGS)
 Datum
 last_day(PG_FUNCTION_ARGS)
 {
-	DateADT day = PG_GETARG_DATEADT(0);
-	DateADT result;
-	int y, m, d;
+	DateADT		day = PG_GETARG_DATEADT(0);
+	DateADT		result;
+	int			y,
+				m,
+				d;
+
 	j2date(day + POSTGRES_EPOCH_JDATE, &y, &m, &d);
-	result = date2j(y, m+1, 1) - POSTGRES_EPOCH_JDATE;
+	result = date2j(y, m + 1, 1) - POSTGRES_EPOCH_JDATE;
 
 	PG_RETURN_DATEADT(result - 1);
 }
@@ -287,7 +291,7 @@ static const int month_days[] = {
 static int
 days_of_month(int y, int m)
 {
-	int	ndays;
+	int			ndays;
 
 	if (m < 0 || 12 < m)
 		ereport(ERROR,
@@ -296,7 +300,7 @@ days_of_month(int y, int m)
 
 	ndays = month_days[m - 1];
 	if (m == 2 && (y % 400 == 0 || (y % 4 == 0 && y % 100 != 0)))
-		ndays += 1;	/* February 29 in leap year */
+		ndays += 1;				/* February 29 in leap year */
 	return ndays;
 }
 
@@ -319,13 +323,17 @@ days_of_month(int y, int m)
 Datum
 months_between(PG_FUNCTION_ARGS)
 {
-	DateADT date1 = PG_GETARG_DATEADT(0);
-	DateADT date2 = PG_GETARG_DATEADT(1);
+	DateADT		date1 = PG_GETARG_DATEADT(0);
+	DateADT		date2 = PG_GETARG_DATEADT(1);
 
-	int y1, m1, d1;
-	int y2, m2, d2;
+	int			y1,
+				m1,
+				d1;
+	int			y2,
+				m2,
+				d2;
 
-	float8 result;
+	float8		result;
 
 	j2date(date1 + POSTGRES_EPOCH_JDATE, &y1, &m1, &d1);
 	j2date(date2 + POSTGRES_EPOCH_JDATE, &y2, &m2, &d2);
@@ -357,13 +365,15 @@ months_between(PG_FUNCTION_ARGS)
 Datum
 add_months(PG_FUNCTION_ARGS)
 {
-	DateADT day = PG_GETARG_DATEADT(0);
-	int n = PG_GETARG_INT32(1);
-	int y, m, d;
-	int	ndays;
-	DateADT result;
-	div_t	v;
-	bool	is_last_day;
+	DateADT		day = PG_GETARG_DATEADT(0);
+	int			n = PG_GETARG_INT32(1);
+	int			y,
+				m,
+				d;
+	int			ndays;
+	DateADT		result;
+	div_t		v;
+	bool		is_last_day;
 
 	j2date(day + POSTGRES_EPOCH_JDATE, &y, &m, &d);
 	is_last_day = (d == days_of_month(y, m));
@@ -371,7 +381,7 @@ add_months(PG_FUNCTION_ARGS)
 	v = div(y * 12 + m - 1 + n, 12);
 	y = v.quot;
 	if (y < 0)
-		y += 1;	/* offset because of year 0 */
+		y += 1;					/* offset because of year 0 */
 	m = v.rem + 1;
 
 	ndays = days_of_month(y, m);
@@ -380,7 +390,7 @@ add_months(PG_FUNCTION_ARGS)
 
 	result = date2j(y, m, d) - POSTGRES_EPOCH_JDATE;
 
-	PG_RETURN_DATEADT (result);
+	PG_RETURN_DATEADT(result);
 }
 
 /*
@@ -393,30 +403,31 @@ add_months(PG_FUNCTION_ARGS)
 
 
 static DateADT
-iso_year (int y, int m, int d)
+iso_year(int y, int m, int d)
 {
-	DateADT		result, day;
+	DateADT		result,
+				day;
 	int			off;
 
-	result = DATE2J(y,1,1);
-	day = DATE2J(y,m,d);
+	result = DATE2J(y, 1, 1);
+	day = DATE2J(y, m, d);
 	off = 4 - J2DAY(result);
-	result += off + ((off >= 0) ? - 3: + 4);  /* to monday */
+	result += off + ((off >= 0) ? -3 : +4); /* to monday */
 
 	if (result > day)
 	{
-		result = DATE2J(y-1,1,1);
+		result = DATE2J(y - 1, 1, 1);
 		off = 4 - J2DAY(result);
-		result += off + ((off >= 0) ? - 3: + 4);  /* to monday */
+		result += off + ((off >= 0) ? -3 : +4); /* to monday */
 	}
 
 	if (((day - result) / 7 + 1) > 52)
 	{
 		DateADT		result2;
 
-		result2 = DATE2J(y+1,1,1);
+		result2 = DATE2J(y + 1, 1, 1);
 		off = 4 - J2DAY(result2);
-		result2 += off + ((off >= 0) ? - 3: + 4);  /* to monday */
+		result2 += off + ((off >= 0) ? -3 : +4);	/* to monday */
 
 		if (day >= result2)
 			return result2;
@@ -428,45 +439,47 @@ iso_year (int y, int m, int d)
 static DateADT
 _ora_date_trunc(DateADT day, int f)
 {
-	int y, m, d;
-	DateADT result;
+	int			y,
+				m,
+				d;
+	DateADT		result;
 
 	j2date(day + POSTGRES_EPOCH_JDATE, &y, &m, &d);
 
 	switch (f)
 	{
-	CASE_fmt_CC
-		if (y > 0)
-			result = DATE2J((y/100)*100+1,1,1);
-		else
-			result = DATE2J(-((99 - (y - 1)) / 100) * 100 + 1,1,1);
-		break;
-	CASE_fmt_YYYY
-		result = DATE2J(y,1,1);
-		break;
-	CASE_fmt_IYYY
-		result = iso_year(y,m,d);
-		break;
-	CASE_fmt_MON
-		result = DATE2J(y,m,1);
-		break;
-	CASE_fmt_WW
-		result = day - (day - DATE2J(y,1,1)) % 7;
-		break;
-	CASE_fmt_IW
-		result = day - (day - iso_year(y,m,d)) % 7;
-		break;
-	CASE_fmt_W
-		result = day - (day - DATE2J(y,m,1)) % 7;
-		break;
-	CASE_fmt_DAY
-		result = day - J2DAY(day);
-		break;
-	CASE_fmt_Q
-		result = DATE2J(y,((m-1)/3)*3+1,1);
-		break;
-	default:
-		result = day;
+			CASE_fmt_CC
+				if (y > 0)
+				result = DATE2J((y / 100) * 100 + 1, 1, 1);
+			else
+				result = DATE2J(-((99 - (y - 1)) / 100) * 100 + 1, 1, 1);
+			break;
+			CASE_fmt_YYYY
+				result = DATE2J(y, 1, 1);
+			break;
+			CASE_fmt_IYYY
+				result = iso_year(y, m, d);
+			break;
+			CASE_fmt_MON
+				result = DATE2J(y, m, 1);
+			break;
+			CASE_fmt_WW
+				result = day - (day - DATE2J(y, 1, 1)) % 7;
+			break;
+			CASE_fmt_IW
+				result = day - (day - iso_year(y, m, d)) % 7;
+			break;
+			CASE_fmt_W
+				result = day - (day - DATE2J(y, m, 1)) % 7;
+			break;
+			CASE_fmt_DAY
+				result = day - J2DAY(day);
+			break;
+			CASE_fmt_Q
+				result = DATE2J(y, ((m - 1) / 3) * 3 + 1, 1);
+			break;
+		default:
+			result = day;
 	}
 
 	return result;
@@ -475,105 +488,113 @@ _ora_date_trunc(DateADT day, int f)
 static DateADT
 _ora_date_round(DateADT day, int f)
 {
-	int y, m, d, z;
-	DateADT result;
+	int			y,
+				m,
+				d,
+				z;
+	DateADT		result;
 
 	j2date(day + POSTGRES_EPOCH_JDATE, &y, &m, &d);
 
 	switch (f)
 	{
-	CASE_fmt_CC
-		if (y > 0)
-			result = DATE2J((y/100)*100+(day < DATE2J((y/100)*100+50,1,1) ?1:101),1,1);
-		else
-			result = DATE2J((y/100)*100+(day < DATE2J((y/100)*100-50+1,1,1) ?-99:1),1,1);
-		break;
-	CASE_fmt_YYYY
-		result = DATE2J(y+(day<DATE2J(y,7,1)?0:1),1,1);
-		break;
-	CASE_fmt_IYYY
-	{
-		if (day < DATE2J(y,7,1))
-		{
-			result = iso_year(y, m, d);
-		}
-		else
-		{
-			DateADT iy1 = iso_year(y+1, 1, 8);
-			result = iy1;
-
-			if (((day - DATE2J(y,1,1)) / 7 + 1) >= 52)
+			CASE_fmt_CC
+				if (y > 0)
+				result = DATE2J((y / 100) * 100 + (day < DATE2J((y / 100) * 100 + 50, 1, 1) ? 1 : 101), 1, 1);
+			else
+				result = DATE2J((y / 100) * 100 + (day < DATE2J((y / 100) * 100 - 50 + 1, 1, 1) ? -99 : 1), 1, 1);
+			break;
+			CASE_fmt_YYYY
+				result = DATE2J(y + (day < DATE2J(y, 7, 1) ? 0 : 1), 1, 1);
+			break;
+			CASE_fmt_IYYY
 			{
-				bool overl = ((date2j(y+2,1,1)-date2j(y+1,1,1)) == 366);
-				bool isSaturday = (J2DAY(day) == 6);
-
-				DateADT iy2 = iso_year(y+2, 1, 8);
-				DateADT day1 = DATE2J(y+1,1,1);
-				/* exception saturdays */
-				if (iy1 >= (day1) && day >= day1 - 2 && isSaturday)
+				if (day < DATE2J(y, 7, 1))
 				{
-					result = overl?iy2:iy1;
+					result = iso_year(y, m, d);
 				}
-				/* iso year stars in last year and day >= iso year */
-				else if (iy1 <= (day1) && day >= iy1 - 3)
+				else
 				{
-					DateADT cmp = iy1 - (iy1 < day1?0:1);
-					int d2 = J2DAY(day1);
-					/* some exceptions */
-					if ((day >= cmp - 2) && (!(d2 == 3 && overl)))
+					DateADT		iy1 = iso_year(y + 1, 1, 8);
+
+					result = iy1;
+
+					if (((day - DATE2J(y, 1, 1)) / 7 + 1) >= 52)
 					{
-						/* if year don't starts in thursday */
-						if ((d2 < 4 && J2DAY(day) != 5 && !isSaturday)
-							||(d2 == 2 && isSaturday && overl))
+						bool		overl = ((date2j(y + 2, 1, 1) - date2j(y + 1, 1, 1)) == 366);
+						bool		isSaturday = (J2DAY(day) == 6);
+
+						DateADT		iy2 = iso_year(y + 2, 1, 8);
+						DateADT		day1 = DATE2J(y + 1, 1, 1);
+
+						/* exception saturdays */
+						if (iy1 >= (day1) && day >= day1 - 2 && isSaturday)
 						{
-							result = iy2;
+							result = overl ? iy2 : iy1;
+						}
+						/* iso year stars in last year and day >= iso year */
+						else if (iy1 <= (day1) && day >= iy1 - 3)
+						{
+							DateADT		cmp = iy1 - (iy1 < day1 ? 0 : 1);
+							int			d2 = J2DAY(day1);
+
+							/* some exceptions */
+							if ((day >= cmp - 2) && (!(d2 == 3 && overl)))
+							{
+								/* if year don't starts in thursday */
+								if ((d2 < 4 && J2DAY(day) != 5 && !isSaturday)
+									|| (d2 == 2 && isSaturday && overl))
+								{
+									result = iy2;
+								}
+							}
 						}
 					}
 				}
+				break;
 			}
-		}
-		break;
-	}
-	CASE_fmt_MON
-		result = DATE2J(y,m+(day<DATE2J(y,m,16)?0:1),1);
-		break;
-	CASE_fmt_WW
-		z = (day - DATE2J(y,1,1)) % 7;
-		result = day - z + (z < 4?0:7);
-		break;
-	CASE_fmt_IW
-	{
-		z = (day - iso_year(y,m,d)) % 7;
-		result = day - z + (z < 4?0:7);
-		if (((day - DATE2J(y,1,1)) / 7 + 1) >= 52)
-		{
-			/* only for last iso week */
-			DateADT isoyear = iso_year(y+1, 1, 8);
-			if (isoyear > (DATE2J(y+1,1,1)-1))
-				if (day > isoyear - 7)
+			CASE_fmt_MON
+				result = DATE2J(y, m + (day < DATE2J(y, m, 16) ? 0 : 1), 1);
+			break;
+			CASE_fmt_WW
+				z = (day - DATE2J(y, 1, 1)) % 7;
+			result = day - z + (z < 4 ? 0 : 7);
+			break;
+			CASE_fmt_IW
+			{
+				z = (day - iso_year(y, m, d)) % 7;
+				result = day - z + (z < 4 ? 0 : 7);
+				if (((day - DATE2J(y, 1, 1)) / 7 + 1) >= 52)
 				{
-					int _d = J2DAY(day);
-					result -= (_d == 0 || _d > 4?7:0);
+					/* only for last iso week */
+					DateADT		isoyear = iso_year(y + 1, 1, 8);
+
+					if (isoyear > (DATE2J(y + 1, 1, 1) - 1))
+						if (day > isoyear - 7)
+						{
+							int			_d = J2DAY(day);
+
+							result -= (_d == 0 || _d > 4 ? 7 : 0);
+						}
 				}
-		}
-		break;
-	}
-	CASE_fmt_W
-		z = (day - DATE2J(y,m,1)) % 7;
-		result = day - z + (z < 4?0:7);
-		break;
-	CASE_fmt_DAY
-		z = J2DAY(day);
-		if (y > 0)
-			result = day - z + (z < 4?0:7);
-		else
-			result = day + (5 - (z>0?(z>1?z:z+7):7));
-		break;
-	CASE_fmt_Q
-		result = DATE2J(y,((m-1)/3)*3+(day<(DATE2J(y,((m-1)/3)*3+2,16))?1:4),1);
-		break;
-	default:
-		result = day;
+				break;
+			}
+			CASE_fmt_W
+				z = (day - DATE2J(y, m, 1)) % 7;
+			result = day - z + (z < 4 ? 0 : 7);
+			break;
+			CASE_fmt_DAY
+				z = J2DAY(day);
+			if (y > 0)
+				result = day - z + (z < 4 ? 0 : 7);
+			else
+				result = day + (5 - (z > 0 ? (z > 1 ? z : z + 7) : 7));
+			break;
+			CASE_fmt_Q
+				result = DATE2J(y, ((m - 1) / 3) * 3 + (day < (DATE2J(y, ((m - 1) / 3) * 3 + 2, 16)) ? 1 : 4), 1);
+			break;
+		default:
+			result = day;
 	}
 	return result;
 }
@@ -595,21 +616,21 @@ _ora_date_round(DateADT day, int f)
 Datum
 ora_to_date(PG_FUNCTION_ARGS)
 {
-	text *date_txt = PG_GETARG_TEXT_PP(0);
-	Timestamp result;
+	text	   *date_txt = PG_GETARG_TEXT_PP(0);
+	Timestamp	result;
 
 	if (VARSIZE_ANY_EXHDR(date_txt) == 0)
 		PG_RETURN_NULL();
 
 	/*
-	 * Du to an Oracle bug, when we have a format we emit an error
-	 * if the date is before 1582-10-04 with the J format or before
-	 * 1100-03-01 for the other formats.
+	 * Du to an Oracle bug, when we have a format we emit an error if the date
+	 * is before 1582-10-04 with the J format or before 1100-03-01 for the
+	 * other formats.
 	 */
 	if (PG_NARGS() == 2)
 	{
-		text *fmt_txt = PG_GETARG_TEXT_PP(1);
-		Datum newDate;
+		text	   *fmt_txt = PG_GETARG_TEXT_PP(1);
+		Datum		newDate;
 
 		/*
 		 * With Oracle passing en empty string to to_date(txt, fmt) returns
@@ -620,8 +641,8 @@ ora_to_date(PG_FUNCTION_ARGS)
 
 		/* it will return timestamp at GMT */
 		newDate = DirectFunctionCall2(to_timestamp,
-					      PointerGetDatum(date_txt),
-					      PointerGetDatum(fmt_txt));
+									  PointerGetDatum(date_txt),
+									  PointerGetDatum(fmt_txt));
 
 		/* convert to local timestamp */
 		result = DatumGetTimestamp(DirectFunctionCall1(timestamptz_timestamp, newDate));
@@ -635,14 +656,14 @@ ora_to_date(PG_FUNCTION_ARGS)
 			}
 			else
 			{
-				text *buglimit_txt = cstring_to_text("1100-03-01 00:00:00");
-				text *buglimit_fmt = cstring_to_text("YYYY-MM-DD H24:MI:SS");
-				Datum bugDate;
-				Timestamp bugResult;
+				text	   *buglimit_txt = cstring_to_text("1100-03-01 00:00:00");
+				text	   *buglimit_fmt = cstring_to_text("YYYY-MM-DD H24:MI:SS");
+				Datum		bugDate;
+				Timestamp	bugResult;
 
 				bugDate = DirectFunctionCall2(to_timestamp,
-							      PointerGetDatum(buglimit_txt),
-							      PointerGetDatum(buglimit_fmt));
+											  PointerGetDatum(buglimit_txt),
+											  PointerGetDatum(buglimit_fmt));
 
 				bugResult = DatumGetTimestamp(DirectFunctionCall1(timestamptz_timestamp, bugDate));
 
@@ -653,23 +674,23 @@ ora_to_date(PG_FUNCTION_ARGS)
 		PG_RETURN_TIMESTAMP(result);
 	}
 
-	if(nls_date_format && strlen(nls_date_format))
+	if (nls_date_format && strlen(nls_date_format))
 	{
-		Datum newDate;
+		Datum		newDate;
 
 		/* it will return timestamp at GMT */
 		newDate = DirectFunctionCall2(to_timestamp,
-					      PointerGetDatum(date_txt),
-					      CStringGetTextDatum(nls_date_format));
+									  PointerGetDatum(date_txt),
+									  CStringGetTextDatum(nls_date_format));
 
 		/* convert to local timestamp */
 		result = DatumGetTimestamp(DirectFunctionCall1(timestamptz_timestamp, newDate));
 	}
 	else
 		result = DatumGetTimestamp(DirectFunctionCall3(timestamp_in,
-									CStringGetDatum(text_to_cstring(date_txt)),
-									ObjectIdGetDatum(InvalidOid),
-									Int32GetDatum(-1)));
+													   CStringGetDatum(text_to_cstring(date_txt)),
+													   ObjectIdGetDatum(InvalidOid),
+													   Int32GetDatum(-1)));
 
 	PG_RETURN_TIMESTAMP(result);
 }
@@ -692,12 +713,13 @@ ora_to_date(PG_FUNCTION_ARGS)
 Datum
 ora_date_trunc(PG_FUNCTION_ARGS)
 {
-	DateADT day = PG_GETARG_DATEADT(0);
-	text *fmt = PG_GETARG_TEXT_PP(1);
+	DateADT		day = PG_GETARG_DATEADT(0);
+	text	   *fmt = PG_GETARG_TEXT_PP(1);
 
-	DateADT result;
+	DateADT		result;
+
+	int			f = ora_seq_search(VARDATA_ANY(fmt), date_fmt, VARSIZE_ANY_EXHDR(fmt));
 
-	int f = ora_seq_search(VARDATA_ANY(fmt), date_fmt, VARSIZE_ANY_EXHDR(fmt));
 	CHECK_SEQ_SEARCH(f, "round/trunc format string");
 
 	result = _ora_date_trunc(day, f);
@@ -706,7 +728,7 @@ ora_date_trunc(PG_FUNCTION_ARGS)
 
 /*
  * Workaround for access to session_timezone on WIN32,
- * 
+ *
  * session timezone isn't accessed directly, but taken by show_timezone,
  * and reparsed. For better performance, the result is cached in fn_extra.
  *
@@ -716,12 +738,12 @@ get_session_timezone(FunctionCallInfo fcinfo)
 {
 #if defined(WIN32)
 
-	pg_tz *result = (pg_tz *) fcinfo->flinfo->fn_extra;
+	pg_tz	   *result = (pg_tz *) fcinfo->flinfo->fn_extra;
 
 	if (result == NULL)
 	{
 		const char *tzn = show_timezone();
-		void *extra;
+		void	   *extra;
 
 		if (!check_timezone(((char **) &tzn), &extra, PGC_S_CLIENT))
 			elog(ERROR, "cannot to parse timezone \"%s\"", tzn);
@@ -736,8 +758,7 @@ get_session_timezone(FunctionCallInfo fcinfo)
 		 * accept small memory leak - elsewhere exception - broken heap :(
 		 *
 		 *
-		 * cannot be called
-		free( extra );
+		 * cannot be called free( extra );
 		 */
 	}
 
@@ -758,7 +779,7 @@ get_session_timezone(FunctionCallInfo fcinfo)
 static void
 tm_trunc(struct pg_tm *tm, text *fmt, bool *redotz)
 {
-	int f;
+	int			f;
 
 	f = ora_seq_search(VARDATA_ANY(fmt), date_fmt, VARSIZE_ANY_EXHDR(fmt));
 	CHECK_SEQ_SEARCH(f, "round/trunc format string");
@@ -767,42 +788,42 @@ tm_trunc(struct pg_tm *tm, text *fmt, bool *redotz)
 
 	switch (f)
 	{
-	CASE_fmt_IYYY
-	CASE_fmt_WW
-	CASE_fmt_W
-	CASE_fmt_IW
-	CASE_fmt_DAY
-	CASE_fmt_CC
-		j2date(_ora_date_trunc(DATE2J(tm->tm_year, tm->tm_mon, tm->tm_mday), f)
-			   + POSTGRES_EPOCH_JDATE,
-		&tm->tm_year, &tm->tm_mon, &tm->tm_mday);
-		TRUNC_DAY;
-		break;
+			CASE_fmt_IYYY
+				CASE_fmt_WW
+				CASE_fmt_W
+				CASE_fmt_IW
+				CASE_fmt_DAY
+				CASE_fmt_CC
+				j2date(_ora_date_trunc(DATE2J(tm->tm_year, tm->tm_mon, tm->tm_mday), f)
+					   + POSTGRES_EPOCH_JDATE,
+					   &tm->tm_year, &tm->tm_mon, &tm->tm_mday);
+			TRUNC_DAY;
+			break;
 
-	CASE_fmt_YYYY
-		tm->tm_mon = 1;
-		tm->tm_mday = 1;
-		TRUNC_DAY;
-		break;
+			CASE_fmt_YYYY
+				tm->tm_mon = 1;
+			tm->tm_mday = 1;
+			TRUNC_DAY;
+			break;
 
-	CASE_fmt_Q
-		tm->tm_mon = (3*((tm->tm_mon - 1)/3)) + 1;
-		tm->tm_mday = 1;
-		TRUNC_DAY;
-		break;
+			CASE_fmt_Q
+				tm->tm_mon = (3 * ((tm->tm_mon - 1) / 3)) + 1;
+			tm->tm_mday = 1;
+			TRUNC_DAY;
+			break;
 
-	CASE_fmt_MON
-		tm->tm_mday = 1;
-		TRUNC_DAY;
-		break;
+			CASE_fmt_MON
+				tm->tm_mday = 1;
+			TRUNC_DAY;
+			break;
 
-	CASE_fmt_DDD
-		TRUNC_DAY;
-		break;
+			CASE_fmt_DDD
+				TRUNC_DAY;
+			break;
 
-	CASE_fmt_HH
-		tm->tm_min = 0;
-		break;
+			CASE_fmt_HH
+				tm->tm_min = 0;
+			break;
 	}
 }
 
@@ -811,20 +832,21 @@ ora_timestamptz_trunc(PG_FUNCTION_ARGS)
 {
 	TimestampTz timestamp = PG_GETARG_TIMESTAMPTZ(0);
 	TimestampTz result;
-	text *fmt = PG_GETARG_TEXT_PP(1);
-	int tz;
-	fsec_t fsec;
-	struct pg_tm tt, *tm = &tt;
+	text	   *fmt = PG_GETARG_TEXT_PP(1);
+	int			tz;
+	fsec_t		fsec;
+	struct pg_tm tt,
+			   *tm = &tt;
 	const char *tzn;
-	bool redotz = false;
+	bool		redotz = false;
 
 	if (TIMESTAMP_NOT_FINITE(timestamp))
 		PG_RETURN_TIMESTAMPTZ(timestamp);
 
 	if (timestamp2tm(timestamp, &tz, tm, &fsec, &tzn, NULL) != 0)
 		ereport(ERROR,
-					(errcode(ERRCODE_DATETIME_VALUE_OUT_OF_RANGE),
-					 errmsg("timestamp out of range")));
+				(errcode(ERRCODE_DATETIME_VALUE_OUT_OF_RANGE),
+				 errmsg("timestamp out of range")));
 
 	tm_trunc(tm, fmt, &redotz);
 	fsec = 0;
@@ -832,10 +854,10 @@ ora_timestamptz_trunc(PG_FUNCTION_ARGS)
 	if (redotz)
 		tz = DetermineTimeZoneOffset(tm, get_session_timezone(fcinfo));
 
-	if (tm2timestamp(tm, fsec	, &tz, &result) != 0)
+	if (tm2timestamp(tm, fsec, &tz, &result) != 0)
 		ereport(ERROR,
-					(errcode(ERRCODE_DATETIME_VALUE_OUT_OF_RANGE),
-					 errmsg("timestamp out of range")));
+				(errcode(ERRCODE_DATETIME_VALUE_OUT_OF_RANGE),
+				 errmsg("timestamp out of range")));
 
 	PG_RETURN_TIMESTAMPTZ(result);
 }
@@ -859,12 +881,13 @@ ora_timestamptz_trunc(PG_FUNCTION_ARGS)
 Datum
 ora_date_round(PG_FUNCTION_ARGS)
 {
-	DateADT day = PG_GETARG_DATEADT(0);
-	text *fmt = PG_GETARG_TEXT_PP(1);
+	DateADT		day = PG_GETARG_DATEADT(0);
+	text	   *fmt = PG_GETARG_TEXT_PP(1);
 
-	DateADT result;
+	DateADT		result;
+
+	int			f = ora_seq_search(VARDATA_ANY(fmt), date_fmt, VARSIZE_ANY_EXHDR(fmt));
 
-	int f = ora_seq_search(VARDATA_ANY(fmt), date_fmt, VARSIZE_ANY_EXHDR(fmt));
 	CHECK_SEQ_SEARCH(f, "round/trunc format string");
 
 	result = _ora_date_round(day, f);
@@ -879,8 +902,8 @@ ora_date_round(PG_FUNCTION_ARGS)
 static void
 tm_round(struct pg_tm *tm, text *fmt, bool *redotz)
 {
-	int 	f;
-	bool	rounded = true;
+	int			f;
+	bool		rounded = true;
 
 	f = ora_seq_search(VARDATA_ANY(fmt), date_fmt, VARSIZE_ANY_EXHDR(fmt));
 	CHECK_SEQ_SEARCH(f, "round/trunc format string");
@@ -888,76 +911,76 @@ tm_round(struct pg_tm *tm, text *fmt, bool *redotz)
 	/* set rounding rule */
 	switch (f)
 	{
-	CASE_fmt_IYYY
-		NOT_ROUND_MDAY(tm->tm_mday < 8 && tm->tm_mon == 1);
-		NOT_ROUND_MDAY(tm->tm_mday == 30 && tm->tm_mon == 6);
-		if (tm->tm_mday >= 28 && tm->tm_mon == 12 && tm->tm_hour >= 12)
-		{
-			DateADT isoyear = iso_year(tm->tm_year+1, 1, 8);
-			DateADT day0 = DATE2J(tm->tm_year+1,1,1);
-			DateADT dayc = DATE2J(tm->tm_year, tm->tm_mon, tm->tm_mday);
-
-			if ((isoyear <= day0) || (day0 <= dayc + 2))
+			CASE_fmt_IYYY
+				NOT_ROUND_MDAY(tm->tm_mday < 8 && tm->tm_mon == 1);
+			NOT_ROUND_MDAY(tm->tm_mday == 30 && tm->tm_mon == 6);
+			if (tm->tm_mday >= 28 && tm->tm_mon == 12 && tm->tm_hour >= 12)
 			{
-				rounded = false;
+				DateADT		isoyear = iso_year(tm->tm_year + 1, 1, 8);
+				DateADT		day0 = DATE2J(tm->tm_year + 1, 1, 1);
+				DateADT		dayc = DATE2J(tm->tm_year, tm->tm_mon, tm->tm_mday);
+
+				if ((isoyear <= day0) || (day0 <= dayc + 2))
+				{
+					rounded = false;
+				}
 			}
-		}
-		break;
-	CASE_fmt_YYYY
-		NOT_ROUND_MDAY(tm->tm_mday == 30 && tm->tm_mon == 6);
-		break;
-	CASE_fmt_MON
-		NOT_ROUND_MDAY(tm->tm_mday == 15);
-		break;
-	CASE_fmt_Q
-		NOT_ROUND_MDAY(tm->tm_mday == 15 && tm->tm_mon == ((tm->tm_mon-1)/3)*3+2);
-		break;
-	CASE_fmt_WW
-	CASE_fmt_IW
-		/* last day in year */
-		NOT_ROUND_MDAY(DATE2J(tm->tm_year, tm->tm_mon, tm->tm_mday) ==
-		(DATE2J(tm->tm_year+1, 1,1) - 1));
-		break;
-	CASE_fmt_W
-		/* last day in month */
-		NOT_ROUND_MDAY(DATE2J(tm->tm_year, tm->tm_mon, tm->tm_mday) ==
-		(DATE2J(tm->tm_year, tm->tm_mon+1,1) - 1));
-		break;
+			break;
+			CASE_fmt_YYYY
+				NOT_ROUND_MDAY(tm->tm_mday == 30 && tm->tm_mon == 6);
+			break;
+			CASE_fmt_MON
+				NOT_ROUND_MDAY(tm->tm_mday == 15);
+			break;
+			CASE_fmt_Q
+				NOT_ROUND_MDAY(tm->tm_mday == 15 && tm->tm_mon == ((tm->tm_mon - 1) / 3) * 3 + 2);
+			break;
+			CASE_fmt_WW
+				CASE_fmt_IW
+			/* last day in year */
+				NOT_ROUND_MDAY(DATE2J(tm->tm_year, tm->tm_mon, tm->tm_mday) ==
+							   (DATE2J(tm->tm_year + 1, 1, 1) - 1));
+			break;
+			CASE_fmt_W
+			/* last day in month */
+				NOT_ROUND_MDAY(DATE2J(tm->tm_year, tm->tm_mon, tm->tm_mday) ==
+							   (DATE2J(tm->tm_year, tm->tm_mon + 1, 1) - 1));
+			break;
 	}
 
 	switch (f)
 	{
-	/* easier convert to date */
-	CASE_fmt_IW
-	CASE_fmt_DAY
-	CASE_fmt_IYYY
-	CASE_fmt_WW
-	CASE_fmt_W
-	CASE_fmt_CC
-	CASE_fmt_MON
-	CASE_fmt_YYYY
-	CASE_fmt_Q
-		ROUND_MDAY(tm);
-		j2date(_ora_date_round(DATE2J(tm->tm_year, tm->tm_mon, tm->tm_mday), f)
-			   + POSTGRES_EPOCH_JDATE,
-		&tm->tm_year, &tm->tm_mon, &tm->tm_mday);
-		tm->tm_hour = 0;
-		tm->tm_min = 0;
-		*redotz = true;
-		break;
-	CASE_fmt_DDD
-		tm->tm_mday += (tm->tm_hour >= 12)?1:0;
-		tm->tm_hour = 0;
-		tm->tm_min = 0;
-		*redotz = true;
-		break;
-	CASE_fmt_MI
-		tm->tm_min += (tm->tm_sec >= 30)?1:0;
-		break;
-	CASE_fmt_HH
-		tm->tm_hour += (tm->tm_min >= 30)?1:0;
-		tm->tm_min = 0;
-		break;
+			/* easier convert to date */
+			CASE_fmt_IW
+				CASE_fmt_DAY
+				CASE_fmt_IYYY
+				CASE_fmt_WW
+				CASE_fmt_W
+				CASE_fmt_CC
+				CASE_fmt_MON
+				CASE_fmt_YYYY
+				CASE_fmt_Q
+				ROUND_MDAY(tm);
+			j2date(_ora_date_round(DATE2J(tm->tm_year, tm->tm_mon, tm->tm_mday), f)
+				   + POSTGRES_EPOCH_JDATE,
+				   &tm->tm_year, &tm->tm_mon, &tm->tm_mday);
+			tm->tm_hour = 0;
+			tm->tm_min = 0;
+			*redotz = true;
+			break;
+			CASE_fmt_DDD
+				tm->tm_mday += (tm->tm_hour >= 12) ? 1 : 0;
+			tm->tm_hour = 0;
+			tm->tm_min = 0;
+			*redotz = true;
+			break;
+			CASE_fmt_MI
+				tm->tm_min += (tm->tm_sec >= 30) ? 1 : 0;
+			break;
+			CASE_fmt_HH
+				tm->tm_hour += (tm->tm_min >= 30) ? 1 : 0;
+			tm->tm_min = 0;
+			break;
 	}
 
 	tm->tm_sec = 0;
@@ -968,20 +991,21 @@ ora_timestamptz_round(PG_FUNCTION_ARGS)
 {
 	TimestampTz timestamp = PG_GETARG_TIMESTAMPTZ(0);
 	TimestampTz result;
-	text *fmt = PG_GETARG_TEXT_PP(1);
-	int tz;
-	fsec_t fsec;
-	struct pg_tm tt, *tm = &tt;
+	text	   *fmt = PG_GETARG_TEXT_PP(1);
+	int			tz;
+	fsec_t		fsec;
+	struct pg_tm tt,
+			   *tm = &tt;
 	const char *tzn;
-	bool redotz = false;
+	bool		redotz = false;
 
 	if (TIMESTAMP_NOT_FINITE(timestamp))
 		PG_RETURN_TIMESTAMPTZ(timestamp);
 
 	if (timestamp2tm(timestamp, &tz, tm, &fsec, &tzn, NULL) != 0)
 		ereport(ERROR,
-					(errcode(ERRCODE_DATETIME_VALUE_OUT_OF_RANGE),
-					 errmsg("timestamp out of range")));
+				(errcode(ERRCODE_DATETIME_VALUE_OUT_OF_RANGE),
+				 errmsg("timestamp out of range")));
 
 	tm_round(tm, fmt, &redotz);
 	fsec = 0;
@@ -1000,20 +1024,21 @@ ora_timestamptz_round(PG_FUNCTION_ARGS)
 Datum
 ora_timestamp_trunc(PG_FUNCTION_ARGS)
 {
-	Timestamp timestamp = PG_GETARG_TIMESTAMP(0);
-	Timestamp result;
-	text *fmt = PG_GETARG_TEXT_PP(1);
-	fsec_t fsec;
-	struct pg_tm tt, *tm = &tt;
-	bool redotz = false;
+	Timestamp	timestamp = PG_GETARG_TIMESTAMP(0);
+	Timestamp	result;
+	text	   *fmt = PG_GETARG_TEXT_PP(1);
+	fsec_t		fsec;
+	struct pg_tm tt,
+			   *tm = &tt;
+	bool		redotz = false;
 
 	if (TIMESTAMP_NOT_FINITE(timestamp))
 		PG_RETURN_TIMESTAMP(timestamp);
 
 	if (timestamp2tm(timestamp, NULL, tm, &fsec, NULL, NULL) != 0)
 		ereport(ERROR,
-					(errcode(ERRCODE_DATETIME_VALUE_OUT_OF_RANGE),
-					 errmsg("timestamp out of range")));
+				(errcode(ERRCODE_DATETIME_VALUE_OUT_OF_RANGE),
+				 errmsg("timestamp out of range")));
 
 	tm_trunc(tm, fmt, &redotz);
 	fsec = 0;
@@ -1029,20 +1054,21 @@ ora_timestamp_trunc(PG_FUNCTION_ARGS)
 Datum
 ora_timestamp_round(PG_FUNCTION_ARGS)
 {
-	Timestamp timestamp = PG_GETARG_TIMESTAMP(0);
-	Timestamp result;
-	text *fmt = PG_GETARG_TEXT_PP(1);
-	fsec_t fsec;
-	struct pg_tm tt, *tm = &tt;
-	bool	redotz = false;
+	Timestamp	timestamp = PG_GETARG_TIMESTAMP(0);
+	Timestamp	result;
+	text	   *fmt = PG_GETARG_TEXT_PP(1);
+	fsec_t		fsec;
+	struct pg_tm tt,
+			   *tm = &tt;
+	bool		redotz = false;
 
 	if (TIMESTAMP_NOT_FINITE(timestamp))
 		PG_RETURN_TIMESTAMPTZ(timestamp);
 
 	if (timestamp2tm(timestamp, NULL, tm, &fsec, NULL, NULL) != 0)
 		ereport(ERROR,
-					(errcode(ERRCODE_DATETIME_VALUE_OUT_OF_RANGE),
-					 errmsg("timestamp out of range")));
+				(errcode(ERRCODE_DATETIME_VALUE_OUT_OF_RANGE),
+				 errmsg("timestamp out of range")));
 
 	tm_round(tm, fmt, &redotz);
 
@@ -1064,7 +1090,7 @@ ora_timestamp_round(PG_FUNCTION_ARGS)
  *
  * Purpose:
  *
- * Returns statement_timestamp in server time zone 
+ * Returns statement_timestamp in server time zone
  *   Note - server time zone doesn't exists on PostgreSQL - emulated
  *   by orafce_timezone
  *
@@ -1073,18 +1099,18 @@ ora_timestamp_round(PG_FUNCTION_ARGS)
 Datum
 orafce_sysdate(PG_FUNCTION_ARGS)
 {
-	Datum sysdate;
-	Datum sysdate_scaled;
+	Datum		sysdate;
+	Datum		sysdate_scaled;
 
 
 	sysdate = DirectFunctionCall2(timestamptz_zone,
-					CStringGetTextDatum(orafce_timezone),
-					TimestampTzGetDatum(GetCurrentStatementStartTimestamp()));
+								  CStringGetTextDatum(orafce_timezone),
+								  TimestampTzGetDatum(GetCurrentStatementStartTimestamp()));
 
 	/* necessary to cast to timestamp(0) to emulate Oracle's date */
 	sysdate_scaled = DirectFunctionCall2(timestamp_scale,
-						sysdate,
-						Int32GetDatum(0));
+										 sysdate,
+										 Int32GetDatum(0));
 
 	PG_RETURN_DATUM(sysdate_scaled);
 }
@@ -1167,7 +1193,7 @@ orafce_sys_extract_utc_oracle_date(PG_FUNCTION_ARGS)
 #else
 
 	loc_ts = DatumGetTimestampTz(DirectFunctionCall1(timestamp_timestamptz,
-								 PG_GETARG_TIMESTAMP(0)));
+													 PG_GETARG_TIMESTAMP(0)));
 
 #endif
 
